==> kmuddy-0.7.1.tar.gz: kmuddy-0.7.1/kmuddy/dialogs/dlgedittimer.h <==
/***************************************************************************
                          dlgedittimer.h  -  Edit Timer dialog
                             -------------------
    begin                : So mj 10 2003
    copyright            : (C) 2003 by Tomas Mecir
    email                : kmuddy@kmuddy.org
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef DLGEDITTIMER_H
#define DLGEDITTIMER_H

#include <kdialogbase.h>

class cTimer;
class QCheckBox;
class KIntNumInput;
class KLineEdit;

/**
Dialog that is used to edit properties of one timer.
  *@author Tomas Mecir
  */

class dlgEditTimer : public KDialogBase  {
   Q_OBJECT
public: 
  dlgEditTimer (cTimer *t, QWidget *parent=0, const char *name=0);
  ~dlgEditTimer ();
  bool showMe ();
protected:
  void createDialog ();
  
  cTimer *timer;

  KLineEdit *cmd;
  QCheckBox *chksingleshot;
  KIntNumInput *interval;
};

#endif

==> kmuddy-0.8.tar.gz: kmuddy-0.8/kmuddy/dialogs/dlgedittimer.h <==
/***************************************************************************
                          dlgedittimer.h  -  Edit Timer dialog
                             -------------------
    begin                : So mj 10 2003
    copyright            : (C) 2003 by Tomas Mecir
    email                : kmuddy@kmuddy.net
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef DLGEDITTIMER_H
#define DLGEDITTIMER_H

#include <kdialogbase.h>

class cTimer;
class QCheckBox;
class KIntNumInput;
class KLineEdit;

/**
Dialog that is used to edit properties of one timer.
  *@author Tomas Mecir
  */

class dlgEditTimer : public KDialogBase  {
   Q_OBJECT
public: 
  dlgEditTimer (cTimer *t, QWidget *parent=0, const char *name=0);
  ~dlgEditTimer ();
  bool showMe ();
protected:
  void createDialog ();
  
  cTimer *timer;

  KLineEdit *cmd;
  QCheckBox *chksingleshot;
  KIntNumInput *interval;
};

#endif
